#include <wiringPi.h>
#include <wiringPiSPI.h>
#include <stdint.h>
#include <stdio.h>
#include <unistd.h>

#include "LS7366R.h"
#include "influx.h"
#include "ringbuffer.h"

const int CTRL_OUT = 16;
const int INTR_IN  = 19;
const int SPI_CHAN = 0;
const int SPI_SPEED = 1000000;


void isr() {
  static uint32_t lastCounter = 0;

  uint32_t currentCounter = ls7366rReadOTR();

  uint32_t diff = currentCounter - lastCounter;
  lastCounter = currentCounter;

  ringbufferPut(diff);
}

void init() {
  wiringPiSetupGpio();

  wiringPiSPISetup(SPI_CHAN, SPI_SPEED);

  pinMode(CTRL_OUT, OUTPUT);
  digitalWrite(CTRL_OUT, 0);

  pinMode(INTR_IN, INPUT);
  wiringPiISR(INTR_IN, INT_EDGE_RISING, isr);
}

int main (void) {
  init();
  ls7366rInit(SPI_CHAN);

  while (1) {
    uint32_t diff = ringbufferGet();
  
    double f = 1.0 / (((double) diff) / 1000000.0);
    printf("%f\n", f);
    influxSendFrequency(f);
  }
}
